summaryrefslogtreecommitdiffstats
path: root/tdeui/tests/twindowtest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/tests/twindowtest.cpp')
-rw-r--r--tdeui/tests/twindowtest.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/tdeui/tests/twindowtest.cpp b/tdeui/tests/twindowtest.cpp
index 02b47c2d8..77e01d289 100644
--- a/tdeui/tests/twindowtest.cpp
+++ b/tdeui/tests/twindowtest.cpp
@@ -9,36 +9,36 @@
#include <stdlib.h>
#include <kstatusbar.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcombobox.h>
#include <khelpmenu.h>
-#include <kcmdlineargs.h>
-#include <kmenubar.h>
-#include <ktoolbarradiogroup.h>
+#include <tdecmdlineargs.h>
+#include <tdemenubar.h>
+#include <tdetoolbarradiogroup.h>
#include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
#include <tqmultilineedit.h>
#include "twindowtest.h"
-#include <kglobal.h>
+#include <tdeglobal.h>
//#include <dclock.h>
/*
- Ok this is a constructor of our top widget. It inherits KMainWindow.
+ Ok this is a constructor of our top widget. It inherits TDEMainWindow.
In constructor wi will create all of our interface elements:
menubar, toolbar(s), statusbar, and main widget. Non of those
interface is obligatory, i.e. you don't have to use menubar,
toolbars or statusbar if you don't want to. Theoreticly, you
don't need even main widget (but in that case, you'll get blank
- KMainWindow).
+ TDEMainWindow).
*/
static int itemId = 0;
testWindow::testWindow (TQWidget *parent, const char *name)
- : KMainWindow (parent,name)
+ : TDEMainWindow (parent,name)
{
ena=false;
setCaption("test window");
@@ -55,7 +55,7 @@ setAutoSaveSettings();
menuBar->insertItem ("&File", fileMenu);
// We insert item "Exit" with accelerator ALT-Q, and connect
// it to application's exit-slot.
- fileMenu->insertItem ("&Exit", KApplication::kApplication(),
+ fileMenu->insertItem ("&Exit", TDEApplication::kApplication(),
TQT_SLOT( quit() ), ALT + Key_Q );
// Another popup...
@@ -148,12 +148,12 @@ setAutoSaveSettings();
// Now add another button and align it right
pix = BarIcon("exit");
- tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), KApplication::kApplication(),
+ tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), TDEApplication::kApplication(),
TQT_SLOT( quit() ), true, "Exit");
tb->alignItemRight (6);
// Another toolbar
- tb1 = new KToolBar(this, TQMainWindow::DockTop); // this one is normal and has separators
+ tb1 = new TDEToolBar(this, TQMainWindow::DockTop); // this one is normal and has separators
pix = BarIcon("filenew");
@@ -194,7 +194,7 @@ setAutoSaveSettings();
tb1->setToggle(7);
//Create
- rg = new KToolBarRadioGroup (tb1);
+ rg = new TDEToolBarRadioGroup (tb1);
rg->addButton(4);
rg->addButton(5);
@@ -230,7 +230,7 @@ setAutoSaveSettings();
//... and main widget
setCentralWidget (widget);
// This is not strictly related to toolbars, menubars or KMainWindow.
// Setup popup for completions
completions = new TQPopupMenu;
@@ -328,7 +328,7 @@ void testWindow::slotCompletion()
completions->popup(TQCursor::pos()); // This popup should understunf keys up and down
/* This is just an example. KLined automatically sets cursor at end of string
- when ctrl-d or ctrl-s is pressed. KToolBar will also put cursor at end of text in Lined
+ when ctrl-d or ctrl-s is pressed. TDEToolBar will also put cursor at end of text in Lined
after inserting text with setLinedText (...).
*/
@@ -408,7 +408,7 @@ void testWindow::slotExit ()
{
TQPixmap pix;
pix = BarIcon("exit");
- tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), KApplication::kApplication(),
+ tb->insertButton(pix, 6, TQT_SIGNAL(clicked()), TDEApplication::kApplication(),
TQT_SLOT( quit() ), true, "Exit");
tb->alignItemRight (6);
exitB = true;
@@ -502,9 +502,9 @@ void testWindow::slotMakeItem3Current()
int main( int argc, char *argv[] )
{
int i;
- KCmdLineArgs::init(argc, argv, "KWindowTest", "description", "version");
+ TDECmdLineArgs::init(argc, argv, "KWindowTest", "description", "version");
- KApplication *myApp = new KApplication();
+ TDEApplication *myApp = new TDEApplication();
testWindow *test = new testWindow;
myApp->setMainWidget(test);
@@ -230,7 +230,7 @@ setAutoSaveSettings();
//... and main widget
setCentralWidget (widget);
- // This is not strictly related to toolbars, menubars or KMainWindow.
+ // This is not strictly related to toolbars, menubars or TDEMainWindow.
// Setup popup for completions
completions = new TQPopupMenu;